> My zlib implementation for example is consistently 25% faster than the reference version, despite me simply "hand compiling" it straight from the C source.
Have you compared it to Intel's optimized implementation of zlib, at https://github.com/jtkukunas/zlib/ ?
If you can improve on that implementation, please consider submitting a patch.